# enable build of Gtk gui
%define with_gtk 1

# enable build of Qt gui
%define with_qt 0

%define archivename comex-project
%define g_gtk %{name}-gtk
%define g_qt %{name}-qt
%define min_ver 0.1.9
%define comexbase %{name}-base
%define name_ver %{name}-%{version}

Summary:   Console interface for comex project
Name:      comex
Version:   0.1.9
Release:   %mkrel 12
License:   GPLv2
#ExcludeArch: ppc64
Group:     Text tools
Source:    https://github.com/armando-basile/%archivename/archive/%{name}-%{version}.tar.gz
# get sources from https://github.com/armando-basile/comex-project/archive/%{version}.tar.gz
# and rename folder from comex-project to comex
Patch0:    target_framework_4.5.patch
URL:       https://github.com/armando-basile/%archivename/
BuildArch: noarch


BuildRequires: pkgconfig(mono)
BuildRequires: pkgconfig(log4net)

# for Gtk gui
%if %{with_gtk}
BuildRequires: pkgconfig(gapi-2.0)
BuildRequires: glade-sharp2
Provides:      %{g_gtk}
%endif

# for Qt gui
%if %{with_qt}
BuildRequires: qyoto-devel
BuildRequires: qyoto
Provides:      %{g_qt}
%endif

Requires: mono-core
Requires: log4net
Requires: %{comexbase} = 0.1.9
Obsoletes: comex-base < %{min_ver}
Obsoletes: comex-base-devel < %{min_ver}
Obsoletes: comex-gtk < %{min_ver}
Obsoletes: comex-qt < %{min_ver}


%description
Is console interface of a simple application that can be used to exchange
data with smartcards using PC/SC standard readers or smartmouse
phoenix serial reader.


%package base
Summary: Base component for comex project
Group: Office/Utilities
Requires: mono-core
Requires: libpcsclite1

%description base
Is base component of a simple application that can be used to exchange
data with smartcards using PC/SC standard readers or smartmouse
phoenix serial reader.


# for Gtk gui
%if %{with_gtk}
%package gtk
Summary: GTK user interface for comex project
Group: Office/Utilities
Requires:      %{comexbase} = %{version}

%description gtk
GTK user interface of a simple application that can be used to exchange
data with smartcards using PC/SC standard readers or smartmouse
phoenix serial reader.
%endif

# for Qt gui
%if %{with_qt}
%package qt
Summary: Qt user interface for comex project
Group: Office/Utilities
Requires:      %{comexbase} = %{version}
Requires:      qyoto-devel

%description qt
Qt user interface of a simple application that can be used to exchange
data with smartcards using PC/SC standard readers or smartmouse
phoenix serial reader.
%endif


%prep
%setup -q
%autopatch -p1


%build
# build commands
cd %{_builddir}/%{name}-%{version}/build-linux
bash ./build-lnx-%{name}.sh

%if %{with_gtk}
bash ./build-lnx-%{name}-gtk.sh
%endif

%if %{with_qt}
bash ./build-lnx-%{name}-qt.sh
%endif


%install
# create folders if not exists
mkdir -p %{buildroot}%{_prefix}/lib/%{name}
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{comexbase}
mkdir -p %{buildroot}%{_docdir}/%{name}

# install commands
cp -f %{_builddir}/%{name_ver}/%{name}/bin/Debug/%{name}.exe* %{buildroot}%{_prefix}/lib/%{name}/
cp -f %{_builddir}/%{name_ver}/%{name}/bin/Debug/%{comexbase}.dll* %{buildroot}%{_prefix}/lib/%{name}/
cp -rf %{_builddir}/%{name_ver}/%{name}/bin/Debug/Languages %{buildroot}%{_datadir}/%{comexbase}/

# generate bin script
(
cat <<EOF
#!/bin/sh
exec mono "%{_prefix}/lib/%{name}/%{name}.exe" "\$@"
EOF
) >> %{buildroot}%{_bindir}/%{name}
chmod 775 %{buildroot}%{_bindir}/%{name}


# for Gtk gui
%if %{with_gtk}
mkdir -p %{buildroot}%{_docdir}/%{g_gtk}
mkdir -p %{buildroot}%{_datadir}/pixmaps/
mkdir -p %{buildroot}%{_datadir}/applications
cp -f %{_builddir}/%{name_ver}/%{g_gtk}/bin/Debug/%{g_gtk}.* %{buildroot}%{_prefix}/lib/%{name}/
cp -f %{_builddir}/%{name_ver}/resources/Images/%{name}_48.png %{buildroot}%{_datadir}/pixmaps/%{g_gtk}.png
cp -f %{_builddir}/%{name_ver}/%{g_gtk}/Resources/%{g_gtk} %{buildroot}%{_datadir}/applications/%{g_gtk}.desktop

(
cat <<EOF
#!/bin/sh
exec mono "%{_prefix}/lib/%{name}/%{g_gtk}.exe" "\$@"
EOF
) >> %{buildroot}%{_bindir}/%{g_gtk}
chmod 775 %{buildroot}%{_bindir}/%{g_gtk}
%endif


# for Qt gui
%if %{with_qt}
mkdir -p %{buildroot}%{_docdir}/%{g_qt}
mkdir -p %{buildroot}%{_datadir}/pixmaps/
mkdir -p %{buildroot}%{_datadir}/applications
cp -f %{_builddir}/%{name_ver}/%{g_qt}/bin/Debug/%{g_qt}.* %{buildroot}%{_prefix}/lib/%{name}/
cp -f %{_builddir}/%{name_ver}/resources/Images/%{name}_48.png %{buildroot}%{_datadir}/pixmaps/%{g_qt}.png
cp -f %{_builddir}/%{name_ver}/%{g_qt}/Resources/%{g_qt} %{buildroot}%{_datadir}/applications/%{g_qt}.desktop

(
cat <<EOF
#!/bin/sh
exec mono "%{_prefix}/lib/%{name}/%{g_qt}.exe" "\$@"
EOF
) >> %{buildroot}%{_bindir}/%{g_qt}
chmod 775 %{buildroot}%{_bindir}/%{g_qt}
%endif


%files
%doc copying.gpl %{name}/readme.txt
%{_bindir}/%{name}
%_prefix/lib/%{name}/%{name}.exe*


%files base
%_prefix/lib/%{name}/%{comexbase}.dll*
%_datadir/%{comexbase}/Languages/*


%if %{with_gtk}
%files gtk
%doc copying.gpl
%{_bindir}/%{g_gtk}
%_prefix/lib/%{name}/%{g_gtk}.*
%{_datadir}/pixmaps/%{g_gtk}.png
%{_datadir}/applications/%{g_gtk}.desktop
%endif


%if %{with_qt}
%files qt
%doc copying.gpl
%{_bindir}/%{g_qt}
%_prefix/lib/%{name}/%{g_qt}.*
%{_datadir}/pixmaps/%{g_qt}.png
%{_datadir}/applications/%{g_qt}.desktop
%endif



%changelog
* Mon Sep 21 2020 tv <tv> 0.1.9-12.mga8
+ Revision: 1629243
- rebuild for new mono

* Sun Feb 16 2020 umeabot <umeabot> 0.1.9-11.mga8
+ Revision: 1535900
- Mageia 8 Mass Rebuild

* Mon Oct 14 2019 daviddavid <daviddavid> 0.1.9-10.mga8
+ Revision: 1453104
- fix dependency (mono to mono-core)

* Thu Sep 20 2018 umeabot <umeabot> 0.1.9-9.mga7
+ Revision: 1277811
- Mageia 7 Mass Rebuild

* Tue Apr 24 2018 daviddavid <daviddavid> 0.1.9-8.mga7
+ Revision: 1222138
- rebuild for new log4net 2.0.8

* Sat Jun 03 2017 akien <akien> 0.1.9-7.mga6
+ Revision: 1105968
- Disable Qt GUI as qyoto dep was obsoleted

* Mon Apr 04 2016 hman <hman> 0.1.9-6.mga6
+ Revision: 998437
- set target framework to 4.5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ tv <tv>
- rebuild for new log4net

* Mon Nov 09 2015 hman <hman> 0.1.9-3.mga6
+ Revision: 900112
- added obsoletes info
- added qyoto-devel as dependency
- added libpcsclite as requires for base component
- use only one tarball also for subpackages

* Tue Oct 20 2015 hman <hman> 0.1.9-1.mga6
+ Revision: 893035
- bump 0.1.9

* Wed Oct 15 2014 umeabot <umeabot> 0.1.6.1-5.mga5
+ Revision: 749482
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.1.6.1-4.mga5
+ Revision: 678491
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.1.6.1-3.mga4
+ Revision: 503465
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- cleanup spec

* Fri Jan 11 2013 umeabot <umeabot> 0.1.6.1-2.mga3
+ Revision: 348076
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 21 2012 hman <hman> 0.1.6.1-1.mga2
+ Revision: 199162
- imported package comex

